@@ -1,11 +1,15 @@
-from firstimpression.scala import variables
 import socket
 
-svars = variables()
+from firstimpression.scala import ScalaPlayer
+
+scala = ScalaPlayer('WHITELABEL')
+
+svars = scala.variables
+
 
 class Socket:
 
-    def __init__(self, port, ip=''):
+    def __init__(self, port: int, ip: str = ''):
         self.ip = ip
         self.port = port
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
@@ -15,11 +19,12 @@ class Socket:
 
     def get_data(self):
         return self.socket.recvfrom(self.buffer_size)
-    
+
     def close(self):
         self.socket.close()
 
-def change_triggers(data):
+
+def change_triggers(data: str):
     for key in svars:
         if 'Channel' in key:
             svars[key] = False
@@ -28,4 +33,4 @@ def change_triggers(data):
     action = data.split('~')[1]
 
     if action == 'active':
-        svars['Channel.{}'.format(playlist)] = True
\ No newline at end of file
+        svars['Channel.{}'.format(playlist)] = True
